InstallInternalError class
An unexpected internal error occurred within the Google Play Store during installation. Please try again later.
- Inheritance
-
- Object
- PlayxVersionUpdateError
- PlayxInstallError
- InstallInternalError
Constructors
- InstallInternalError()
-
const
Properties
- errorCode → String
-
A unique string code identifying the type of error.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable message describing the error.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited