PlayxVersionUpdateErrorResult<T> class
Represents an error result with an associated error.
- Inheritance
-
- Object
- PlayxVersionUpdateResult<
T> - PlayxVersionUpdateErrorResult
Constructors
- PlayxVersionUpdateErrorResult(PlayxVersionUpdateError error)
-
const
Properties
- error → PlayxVersionUpdateError
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
Check if the result is an error.
no setterinherited
- isSuccess → bool
-
Check if the result is a success.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateData → T?
-
no setterinherited
- updateError → PlayxVersionUpdateError?
-
no setterinherited
Methods
-
copyWith(
{PlayxVersionUpdateError? error}) → PlayxVersionUpdateErrorResult< T> - Creates a copy of this result with a modified error value.
-
map<
S> ({required PlayxVersionUpdateResult< S> success(T data), required PlayxVersionUpdateResult<S> error(PlayxVersionUpdateError error)}) → PlayxVersionUpdateResult<S> -
Maps the success data or propagates the error while transforming the type.
inherited
-
mapAsync<
S> ({required Future< PlayxVersionUpdateResult< success(T data), required Future<S> >PlayxVersionUpdateResult< error(PlayxVersionUpdateError error)}) → Future<S> >PlayxVersionUpdateResult< S> > -
Asynchronous version of
map, allowing transformations withFuture.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
R> ({required R success(T data), required R error(PlayxVersionUpdateError error)}) → R -
Executes the appropriate callback based on the result type.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited